<?php
/**
 * Custom Functions.
 *
 * @package Dolpa
 */

if( !function_exists( 'dolpa_fonts_url' ) ) :

    //Google Fonts URL
    function dolpa_fonts_url(){

        $fonts_url = '';
        $fonts = array();

        $dolpa_font_1 = 'Open+Sans:ital,wght@0,300;0,400;0,600;0,700;0,800;1,300;1,400;1,600;1,700;1,800&display=swap';
        
        $dolpa_fonts = array();
        $dolpa_fonts[] = $dolpa_font_1;

        $dolpa_fonts_stylesheet = '//fonts.googleapis.com/css?family=';

        $i = 0;
        for ( $i = 0; $i < count( $dolpa_fonts ); $i++ ) {

            if ( 'off' !== sprintf( _x( 'on', '%s font: on or off', 'dolpa' ), $dolpa_fonts[$i] ) ) {
                $fonts[] = $dolpa_fonts[$i];
            }

        }

        if ( $fonts ) {
            $fonts_url = add_query_arg( array(
                'family' => urldecode( implode( '|', $fonts ) ),
            ), 'https://fonts.googleapis.com/css' );
        }

        return esc_url_raw($fonts_url);
    }

endif;

if( !function_exists('dolpa_sanitize_sidebar_option_meta') ) :

    // Sidebar Option Sanitize.
    function dolpa_sanitize_sidebar_option_meta($input){

        $metabox_options = array('global-sidebar', 'left-sidebar', 'right-sidebar', 'no-sidebar');

        if( in_array($input, $metabox_options) ){

            return $input;

        } else {

            return '';

        }

    }

endif;

if( !function_exists('dolpa_page_lists')):

    // Page List.
    function dolpa_page_lists(){

        $page_lists = array();
        $page_lists[''] = esc_html__('Select Page', 'dolpa');

        $pages = get_pages(
            array(
                'parent' => 0, // replaces 'depth' => 1,
            )
        );

        foreach( $pages as $page ){

            $page_lists[$page->ID] = $page->post_title;

        }

        return $page_lists;
    }

endif;

if( !function_exists('dolpa_sanitize_post_layout_option_meta') ):

    // Sidebar Option Sanitize.

    function dolpa_sanitize_post_layout_option_meta($input){

        $metabox_options = array('global-layout', 'layout-1', 'layout-2');

        if( in_array($input, $metabox_options) ){

            return $input;

        } else {

            return '';

        }

    }

endif;

if( !function_exists('dolpa_sanitize_header_overlay_option_meta') ):

    // Sidebar Option Sanitize.

    function dolpa_sanitize_header_overlay_option_meta($input){

        $metabox_options = array('global-layout', 'enable-overlay');
        if (in_array($input, $metabox_options)) {

            return $input;

        } else {

            return '';

        }
    }

endif;

if( !function_exists('dolpa_the_theme_svg') ):

    /**
     * Output and Get Theme SVG.
     * Output and get the SVG markup for an icon in the Dolpa_SVG_Icons class.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function dolpa_the_theme_svg($svg_name, $return = false){

        if ($return) {

            return dolpa_get_theme_svg($svg_name); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in dolpa_get_theme_svg();.

        } else {

            echo dolpa_get_theme_svg($svg_name); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in dolpa_get_theme_svg();.

        }
    }

endif;

if( !function_exists('dolpa_get_theme_svg') ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */

    function dolpa_get_theme_svg($svg_name){

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            Dolpa_SVG_Icons::get_svg($svg_name),
            array(
                'svg' => array(
                    'class' => true,
                    'xmlns' => true,
                    'width' => true,
                    'height' => true,
                    'viewbox' => true,
                    'aria-hidden' => true,
                    'role' => true,
                    'focusable' => true,
                ),
                'path' => array(
                    'fill' => true,
                    'fill-rule' => true,
                    'd' => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill' => true,
                    'fill-rule' => true,
                    'points' => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );

        if (!$svg) {

            return false;

        }

        return $svg;

    }

endif;

if( !function_exists('dolpa_sub_menu_toggle_button') ):

    function dolpa_sub_menu_toggle_button($args, $item, $depth){

        // Add sub menu toggles to the main menu with toggles
        if ($args->theme_location == 'dolpa-primary-menu' && isset($args->show_toggles)) {

            // Wrap the menu item link contents in a div, used for positioning
            $args->before = '<div class="submenu-wrapper">';
            $args->after = '';

            // Add a toggle to items with children
            if (in_array('menu-item-has-children', $item->classes)) {

                $toggle_target_string = '.menu-item.menu-item-' . $item->ID . ' > .sub-menu';

                // Add the sub menu toggle
                $args->after .= '<button type="button" class="button-style button-transparent submenu-toggle" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250"><span class="screen-reader-text">' . __('Show sub menu', 'dolpa') . '</span>' . dolpa_get_theme_svg('chevron-down') . '</button>';

            }
            // Close the wrapper
            $args->after .= '</div><!-- .submenu-wrapper -->';
            // Add sub menu icons to the main menu without toggles (the fallback menu)

        } elseif ($args->theme_location == 'dolpa-primary-menu') {

            if (in_array('menu-item-has-children', $item->classes)) {

                $args->before = '<div class="link-icon-wrapper">';
                $args->after = dolpa_get_theme_svg('chevron-down') . '</div>';

            } else {

                $args->before = '';
                $args->after = '';

            }

        }

        return $args;
    }

endif;

add_filter('nav_menu_item_args', 'dolpa_sub_menu_toggle_button', 10, 3);

if( !function_exists('dolpa_post_category_list') ) :

    // Post Category List.
    function dolpa_post_category_list($select_cat = true){

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
            )
        );

        $post_cat_cat_array = array();
        if( $select_cat ){
            $post_cat_cat_array[''] = esc_html__('Select Category', 'dolpa');
        }

        foreach( $post_cat_lists as $post_cat_list ){

            $post_cat_cat_array[$post_cat_list->slug] = $post_cat_list->name;

        }

        return $post_cat_cat_array;
    }

endif;

if ( !function_exists('dolpa_sanitize_meta_pagination') ):

    /** Sanitize Enable Disable Checkbox **/
    function dolpa_sanitize_meta_pagination($input){

        $valid_keys = array('global-layout', 'no-navigation', 'normal-navigation', 'ajax-next-post-load');
        
        if (in_array($input, $valid_keys)) {
            return $input;
        }

        return '';
    }

endif;

if( !function_exists('dolpa_single_post_navigation') ):

    function dolpa_single_post_navigation(){

        $dolpa_default = dolpa_get_default_theme_options();
        $theme_navigation_type = get_post_meta(get_the_ID(), 'theme_disable_ajax_load_next_post', true);
        $dolpa_archive_layout = get_theme_mod('dolpa_archive_layout', $dolpa_default['dolpa_archive_layout'] );
        $current_id = '';
        $article_wrap_class = '';
        global $post;
        $current_id = $post->ID;

        if ($theme_navigation_type == '' || $theme_navigation_type == 'global-layout') {
            $theme_navigation_type = get_theme_mod('theme_navigation_type', $dolpa_default['theme_navigation_type']);
        }

        if($theme_navigation_type != 'no-navigation' && 'post' === get_post_type()) {

            if($theme_navigation_type == 'normal-navigation') { ?>

                <div class="navigation-wrapper">

                    <?php
                    // Previous/next post navigation.
                    the_post_navigation(array(
                        'prev_text' => '<span class="arrow" aria-hidden="true">' . dolpa_the_theme_svg('arrow-left', $return = true) . '</span><span class="screen-reader-text">' . __('Previous post:', 'dolpa') . '</span><span class="post-title">%title</span>',
                        'next_text' => '<span class="arrow" aria-hidden="true">' . dolpa_the_theme_svg('arrow-right', $return = true) . '</span><span class="screen-reader-text">' . __('Next post:', 'dolpa') . '</span><span class="post-title">%title</span>',
                    )); ?>

                </div>

            <?php
            } else {

                $next_post = get_next_post();
                if (isset($next_post->ID)) {
                    $next_post_id = $next_post->ID;
                    echo '<div loop-count="1" next-post="' . absint($next_post_id) . '" class="theme-single-infinity"></div>';
                }

            }

        }

    }

endif;

add_action('dolpa_navigation_action', 'dolpa_single_post_navigation', 30);

if( !function_exists('dolpa_template_banner') ):

    function dolpa_template_banner(){

        $dolpa_default = dolpa_get_default_theme_options();
        if( is_page_template('templates/template-cover.php') ||
            is_page_template('templates/template-carousel.php') ||
            is_page_template('templates/template-slider.php') ){

            if( is_page_template('templates/template-cover.php') ) {

                $ed_banner = get_theme_mod('ed_template_cover_banner', $dolpa_default['ed_template_cover_banner']);

            } elseif (is_page_template('templates/template-carousel.php')) {

                $ed_banner = get_theme_mod('ed_template_carousel_banner', $dolpa_default['ed_template_carousel_banner']);

            } elseif (is_page_template('templates/template-slider.php')) {

                $ed_banner = get_theme_mod('ed_template_slider_banner', $dolpa_default['ed_template_slider_banner']);

            }

            if ($ed_banner && have_posts()) :

                while (have_posts()) :
                    the_post();

                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                    $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>

                    <div class="featured-cover-banner featured-default-banner">

                        <div class="featured-banner-content">
                            <div class="wrapper">
                                <div class="wrapper-inner">
                                    <div class="column column-12">

                                        <header class="entry-header">
                                            <h1 class="entry-title entry-title-large bbb"><?php the_title(); ?></h1>
                                        </header>

                                        <a class="scroll-content">
                                            <span class="mouse"><span></span></span>
                                        </a>

                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="featured-banner-media">
                            <div class="data-bg data-bg-fixed data-bg-banner" <?php if ($featured_image){ ?>data-background="<?php echo esc_url($featured_image); ?>" <?php } ?> ></div>
                        </div>
                    </div>

                <?php
                endwhile;

            endif;
        }
    }
endif;

if( !function_exists('dolpa_header_banner') ):

    function dolpa_header_banner(){

        global $post;
        $dolpa_post_layout = '';
        $dolpa_default = dolpa_get_default_theme_options();

        if( is_singular() ) {

            $dolpa_post_layout = get_post_meta($post->ID, 'dolpa_post_layout', true);

            if ($dolpa_post_layout == '' || $dolpa_post_layout == 'global-layout') {

                $dolpa_post_layout = get_theme_mod( 'dolpa_single_post_layout', $dolpa_default['dolpa_archive_layout'] );

            }
            
        }

        $dolpa_page_layout = '';
        if( isset( $post->ID ) ){
            $dolpa_page_layout = get_post_meta($post->ID, 'dolpa_page_layout', true);
        }

        if( is_page_template('templates/template-carousel.php') ){

            $slider_cat = get_theme_mod('template_carousel_slider_category');

            if( $slider_cat ){

                $slider_arrows = esc_html(get_theme_mod('ed_template_carousel_arrow', $dolpa_default['ed_template_carousel_arrow']));
                $slider_dots = esc_html(get_theme_mod('ed_template_carousel_dots', $dolpa_default['ed_template_carousel_dots']));
                $slider_autoplay = esc_html(get_theme_mod('ed_template_carousel_autoplay', $dolpa_default['ed_template_carousel_autoplay']));

                if ($slider_autoplay) {
                    $autoplay = 'true';
                } else {
                    $autoplay = 'false';
                }
                if ($slider_dots) {
                    $dots = 'true';
                } else {
                    $dots = 'false';
                }
                if ($slider_arrows) {
                    $arrows = 'true';
                } else {
                    $arrows = 'false';
                }
                if (is_rtl()) {
                    $rtl = 'true';
                } else {
                    $rtl = 'false';
                }

                $slider_cat_query = new WP_Query( array('post_type' => 'post', 'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html( $slider_cat ) ) ); ?>

                <div class="template-carousel-main">

                    <?php if ($slider_cat_query->have_posts()): ?>

                        <div class="wrapper">
                            <div class="wrapper-inner">
                                <div class="column column-12">
                                    <div class="template-carousel-slide" data-slick='{"autoplay": <?php echo esc_attr($autoplay); ?>, "dots": <?php echo esc_attr($dots); ?>, "arrows": <?php echo esc_attr($arrows); ?>, "rtl": <?php echo esc_attr($rtl); ?>}'>

                                        <?php
                                        while ($slider_cat_query->have_posts()):
                                            $slider_cat_query->the_post();
                                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large');
                                            $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>

                                            <div class="theme-carousel-item theme-slick-item">
                                                <article id="post-<?php the_ID(); ?>" <?php post_class('theme-article theme-article-alt'); ?>>
                                                    <div class="post-thumbnail">

                                                        <div class="post-thumbnail-effects">
                                                            <a href="<?php the_permalink(); ?>">
                                                                <span class="data-bg data-bg-large" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                                            </a>

                                                            <?php
                                                            $format = get_post_format(get_the_ID()) ?: 'standard';
                                                            $icon = dolpa_post_format_icon($format);
                                                            if (!empty($icon)) { ?>

                                                                <div class="post-format-icon"><i class="ion <?php echo esc_attr($icon); ?>"></i></div>
                                                            
                                                            <?php } ?>

                                                        </div>

                                                        <div class="post-thumbnail-overlay">
                                                            <?php
                                                            if ('post' === get_post_type()) { ?>

                                                                <div class="entry-meta">

                                                                    <?php dolpa_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>

                                                                </div>

                                                            <?php } ?>
                                                        </div>

                                                    </div>

                                                    <div class="post-content">

                                                        <div class="entry-meta">
                                                            <?php
                                                            dolpa_posted_on();
                                                            dolpa_posted_by();
                                                            ?>
                                                        </div>

                                                        <header class="entry-header">
                                                            <h2 class="entry-title entry-title-medium">
                                                                <a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a>
                                                            </h2>
                                                        </header>

                                                    </div>

                                                </article>
                                            </div>

                                        <?php endwhile; ?>

                                    </div>
                                </div>
                            </div>
                        </div>

                        <?php
                        wp_reset_postdata();

                    endif; ?>

                </div>
                <?php
            }
        }elseif( is_page_template('templates/template-slider.php') ) {

            $slider_cat = get_theme_mod('template_slider_category');

            if( $slider_cat ){

                $slider_arrows = get_theme_mod( 'ed_template_slider_arrows', $dolpa_default['ed_template_slider_arrows'] );
                $slider_dots = get_theme_mod( 'ed_template_slider_dots', $dolpa_default['ed_template_slider_dots'] );
                $slider_autoplay = get_theme_mod( 'ed_template_slider_autoplay', $dolpa_default['ed_template_slider_autoplay'] );

                if ($slider_autoplay) {
                    $autoplay = 'true';
                } else {
                    $autoplay = 'false';
                }
                if ($slider_dots) {
                    $dots = 'true';
                } else {
                    $dots = 'false';
                }
                if ($slider_arrows) {
                    $arrows = 'true';
                } else {
                    $arrows = 'false';
                }
                if (is_rtl()) {
                    $rtl = 'true';
                } else {
                    $rtl = 'false';
                }
                $slider_cat_query = new WP_Query(array('post_type' => 'post', 'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html($slider_cat))); ?>

                <div class="template-slider-main">
                    <?php if ($slider_cat_query->have_posts()): ?>
                        <div class="wrapper">
                            <div class="wrapper-inner">
                                <div class="slick-slide-wrapper">
                                    <div class="template-slide"
                                         data-slick='{"autoplay": <?php echo esc_attr($autoplay); ?>, "dots": <?php echo esc_attr($dots); ?>, "arrows": <?php echo esc_attr($arrows); ?>, "rtl": <?php echo esc_attr($rtl); ?>}'>
                                        <?php
                                        while ($slider_cat_query->have_posts()):
                                            $slider_cat_query->the_post();
                                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                                            $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>
                                            <div class="theme-slider-item theme-slick-item">
                                                <article id="post-<?php the_ID(); ?>" <?php post_class('theme-article theme-article-alt'); ?>>
                                                    <div class="post-thumbnail">
                                                        <div class="post-thumbnail-effects">
                                                            <a href="<?php the_permalink(); ?>">
                                                                <span class="data-bg data-bg-large" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                                            </a>
                                                            <?php
                                                            $format = get_post_format(get_the_ID()) ?: 'standard';
                                                            $icon = dolpa_post_format_icon($format);
                                                            if (!empty($icon)) { ?>
                                                                <div class="post-format-icon"><i class="ion <?php echo esc_attr($icon); ?>"></i></div>
                                                            <?php } ?>
                                                        </div>
                                                        <div class="post-thumbnail-overlay">
                                                            <?php
                                                            if ('post' === get_post_type()) { ?>
                                                                <div class="entry-meta">
                                                                    <?php dolpa_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                                                                </div>
                                                            <?php } ?>
                                                        </div>
                                                    </div>
                                                    <div class="post-content">
                                                        <div class="entry-meta">
                                                            <?php
                                                            dolpa_posted_on();
                                                            dolpa_posted_by();
                                                            ?>
                                                        </div>
                                                        <header class="entry-header">
                                                            <h2 class="entry-title entry-title-large ccc">
                                                                <a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a>
                                                            </h2>
                                                        </header>
                                                    </div>
                                                </article>
                                            </div>
                                        <?php endwhile; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php
                        wp_reset_postdata();
                    endif; ?>
                </div>
                <?php
            }
        }elseif ($dolpa_post_layout == 'layout-2' && !is_page_template('templates/template-cover.php') && !is_page_template('templates/template-slider.php') && !is_page_template('templates/template-carousel.php') && is_singular('post')) {
            if (have_posts()) :
                while (have_posts()) :
                    the_post();
                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                    $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : '';
                    $dolpa_ed_feature_image = esc_html(get_post_meta(get_the_ID(), 'dolpa_ed_feature_image', true));
                    ?>
                    <div class="single-featured-banner  <?php if (empty($dolpa_ed_feature_image) && $featured_image) {
                        echo 'banner-has-image';
                    } ?>">
                        <div class="featured-banner-content">
                            <div class="wrapper">
                                <div class="wrapper-inner">
                                    <div class="column column-12">
                                        <?php
                                        if (!is_404() && !is_home() && !is_front_page()) {
                                            dolpa_breadcrumb();
                                        } ?>
                                    </div>
                                </div>
                                <div class="wrapper-inner">
                                    <div class="column column-12">
                                        <?php
                                        if ('post' === get_post_type()) { ?>
                                            <div class="entry-meta">
                                                <?php dolpa_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                                            </div>
                                        <?php } ?>
                                        <header class="entry-header">
                                            <h1 class="entry-title entry-title-large ddd">
                                                <?php the_title(); ?>
                                            </h1>
                                        </header>
                                        <div class="entry-meta entry-meta-footer">
                                            <?php
                                            dolpa_posted_by();
                                            dolpa_posted_on();
                                            ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php if (empty($dolpa_ed_feature_image) && $featured_image) { ?>
                            <div class="featured-banner-media">
                                <div class="data-bg data-bg-fixed data-bg-banner" data-background="<?php echo esc_url($featured_image); ?>"></div>
                            </div>
                        <?php } ?>
                    </div>
                <?php
                endwhile;
            endif;
        }elseif ($dolpa_page_layout == 'layout-2' && !is_page_template('templates/template-cover.php') && !is_page_template('templates/template-slider.php') && !is_page_template('templates/template-carousel.php') && is_singular('page')) {
            if (have_posts()) :
                while (have_posts()) :
                    the_post();
                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                    $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : '';
                    $dolpa_ed_feature_image = esc_html(get_post_meta(get_the_ID(), 'dolpa_ed_feature_image', true));
                    ?>
                    <div class="single-featured-banner  <?php if (empty($dolpa_ed_feature_image) && $featured_image) {
                        echo 'banner-has-image';
                    } ?>">
                        <div class="featured-banner-content">
                            <div class="wrapper">
                                <div class="wrapper-inner">
                                    <div class="column column-12">
                                        <?php
                                        if (!is_404() && !is_home() && !is_front_page()) {
                                            dolpa_breadcrumb();
                                        } ?>
                                    </div>
                                </div>
                                <div class="wrapper-inner">
                                    <div class="column column-12">
                                        <header class="entry-header">
                                            <h1 class="entry-title entry-title-large eee">
                                                <?php the_title(); ?>
                                            </h1>
                                        </header>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php if (empty($dolpa_ed_feature_image) && $featured_image) { ?>
                            <div class="featured-banner-media">
                                <div class="data-bg data-bg-fixed data-bg-banner" data-background="<?php echo esc_url($featured_image); ?>"></div>
                            </div>
                        <?php } ?>
                    </div>
                <?php
                endwhile;
            endif;
        }
    }

endif;

if (!function_exists('dolpa_header_toggle_search')):

    /**
     * Header Search
     **/
    function dolpa_header_toggle_search()
    {
        $dolpa_default = dolpa_get_default_theme_options();
        $dolpa_header_search = get_theme_mod('dolpa_header_search', $dolpa_default['dolpa_header_search']);
        $ed_header_search_top_category = get_theme_mod( 'ed_header_search_top_category', $dolpa_default['ed_header_search_top_category'] );
        $ed_header_search_recent_posts = absint( get_theme_mod( 'ed_header_search_recent_posts',$dolpa_default['ed_header_search_recent_posts'] ) );

        if ($dolpa_header_search) { ?>
            <div class="header-searchbar">
                <div class="header-searchbar-inner">
                    <div class="wrapper">
                        <div class="header-searchbar-panel">
                            <div class="header-searchbar-area">

                                <a class="skip-link-search-top" href="javascript:void(0)"></a>

                                <?php get_search_form(); ?>

                            </div>

                            <?php if( $ed_header_search_recent_posts || $ed_header_search_top_category ){ ?>

                                <div class="search-content-area">

                                    <?php if( $ed_header_search_recent_posts ){ ?>

                                        <div class="search-recent-posts">
                                            <?php dolpa_recent_posts_search(); ?>
                                        </div>

                                    <?php } ?>

                                    <?php if( $ed_header_search_top_category ){ ?>

                                        <div class="search-popular-categories">
                                            <?php dolpa_header_search_top_cat_content(); ?>
                                        </div>

                                    <?php } ?>

                                </div>

                            <?php } ?>

                            <button type="button" id="search-closer" class="button-style button-transparent close-popup">
                                <?php dolpa_the_theme_svg('cross'); ?>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }
    }

endif;

add_action('dolpa_before_footer_content_action', 'dolpa_header_toggle_search', 10);

if( !function_exists('dolpa_recent_posts_search') ):

    // Single Posts Related Posts.
    function dolpa_recent_posts_search(){

        $dolpa_default = dolpa_get_default_theme_options();
        $related_posts_query = new WP_Query( array('post_type' => 'post', 'posts_per_page' => 5,'post__not_in' => get_option("sticky_posts") ) );

        if( $related_posts_query->have_posts() ): ?>

            <div class="theme-block related-search-posts">

                <div class="theme-block-heading">
                    <?php
                    $recent_post_title_search = esc_html( get_theme_mod( 'recent_post_title_search',$dolpa_default['recent_post_title_search'] ) );

                    if( $recent_post_title_search ){ ?>
                        <h2 class="theme-block-title">

                            <?php echo esc_html( $recent_post_title_search ); ?>

                        </h2>
                    <?php } ?>
                </div>

                <div class="theme-list-group recent-list-group">

                    <?php
                    while( $related_posts_query->have_posts() ):
                        $related_posts_query->the_post(); ?>

                        <article id="post-<?php the_ID(); ?>" <?php post_class('theme-list-article'); ?>>
                            <header class="entry-header">
                                <h3 class="entry-title">
                                    <a href="<?php the_permalink(); ?>" rel="bookmark">
                                        <?php the_title(); ?>
                                    </a>
                                </h3>
                            </header>
                        </article>

                    <?php 
                    endwhile; ?>

                </div>

            </div>

            <?php
            wp_reset_postdata();

        endif;

    }

endif;

if( !function_exists('dolpa_header_search_top_cat_content') ):

    function dolpa_header_search_top_cat_content(){

        $top_category = 3;

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $slug_counts = array();

        foreach( $post_cat_lists as $post_cat_list ){

            if( $post_cat_list->count >= 1 ){

                $slug_counts[] = array( 
                    'count'         => $post_cat_list->count,
                    'slug'          => $post_cat_list->slug,
                    'name'          => $post_cat_list->name,
                    'cat_ID'        => $post_cat_list->cat_ID,
                    'description'   => $post_cat_list->category_description, 
                );

            }

        }

        if( $slug_counts ){?>

            <div class="theme-block popular-search-categories">
                
                <div class="theme-block-heading">
                    <?php
                    $dolpa_default = dolpa_get_default_theme_options();
                    $top_category_title_search = esc_html( get_theme_mod( 'top_category_title_search',$dolpa_default['top_category_title_search'] ) );

                    if( $top_category_title_search ){ ?>
                        <h2 class="theme-block-title">

                            <?php echo esc_html( $top_category_title_search ); ?>

                        </h2>
                    <?php } ?>
                </div>

                <?php
                arsort( $slug_counts ); ?>

                <div class="theme-list-group categories-list-group">
                    <div class="wrapper-inner">

                        <?php
                        $i = 1;
                        foreach( $slug_counts as $key => $slug_count ){

                            if( $i > $top_category){ break; }
                            
                            $cat_link           = get_category_link( $slug_count['cat_ID'] );
                            $cat_name           = $slug_count['name'];
                            $cat_slug           = $slug_count['slug'];
                            $cat_count          = $slug_count['count'];
                            $twp_term_image = get_term_meta( $slug_count['cat_ID'], 'twp-term-featured-image', true ); ?>

                            <div class="column column-4 column-sm-12">
                                <article id="post-<?php the_ID(); ?>" <?php post_class('theme-category-article'); ?>>
                                    <div class="article-area">
                                        <div class="article-panel">
                                            <div class="entry-thumbnail">
                                                    <a href="<?php echo esc_url($cat_link); ?>" class="data-bg data-bg-small" data-background="<?php echo esc_url($twp_term_image); ?>"></a>
                                            </div>
                                            <div class="entry-details">
                                                <header class="entry-header">
                                                    <h3 class="entry-title">
                                                        <a href="<?php echo esc_url($cat_link); ?>">
                                                            <?php echo esc_html($cat_name); ?>
                                                        </a>
                                                    </h3>
                                                </header>
                                            </div>
                                        </div>
                                    </div>
                                </article>
                            </div>
                            <?php
                            $i++;

                        } ?>

                    </div>
                </div>

            </div>
        <?php
        }

    }

endif;

if (!function_exists('dolpa_content_gallery')):

    // Gallery Contents
    function dolpa_content_gallery()
    { ?>
        <div class="footer-gallery-wrap">
            <div class="wrapper">
                <?php
                if (is_singular('post') || is_singular('page')) {
                    if (function_exists('has_block') && has_block('gallery', get_the_content())) {
                        echo '<div class="footer-galleries">';
                        $post_blocks = parse_blocks(get_the_content());
                        if ($post_blocks) {
                            foreach ($post_blocks as $post_block) {
                                if (isset($post_block['blockName']) &&
                                    isset($post_block['innerHTML']) &&
                                    $post_block['blockName'] == 'core/gallery') {
                                    
                                    echo '<div class="footer-gallery-sec-wrap">';
                                    echo wp_kses_post( $post_block['innerHTML'] );
                                    echo '</div>';
                                
                                }
                            }
                        }
                        echo '</div>';
                    }
                }
                echo '<div class="widget-footer-galleries">';
                echo '</div>'; ?>
            </div>
        </div>
        <?php
    }

endif;

add_action('dolpa_before_footer_content_action', 'dolpa_content_gallery', 20);

if (!function_exists('dolpa_content_offcanvas')):

    // Offcanvas Contents
    function dolpa_content_offcanvas()
    { ?>
        <div id="offcanvas-menu">
            <div class="offcanvas-wraper">
                <div class="close-offcanvas-menu">

                    <a class="skip-link-off-canvas" href="javascript:void(0)"></a>

                    <div class="offcanvas-close">
                        <button type="button" class="button-style button-transparent button-offcanvas-close">
                            <span class="bars">
                                    <span class="bar"></span>
                                    <span class="bar"></span>
                                    <span class="bar"></span>
                                </span>
                        </button>
                    </div>
                </div>

                <div id="primary-nav-offcanvas" class="offcanvas-item offcanvas-main-navigation">
                    <?php wp_nav_menu(array(
                        'theme_location' => 'dolpa-primary-menu',
                        'container' => 'div',
                        'container_class' => 'offcanvas-navigation-area',
                        'show_toggles' => true,
                    )); ?>
                </div>

                <?php if (has_nav_menu('dolpa-social-menu')) { ?>
                    <div id="social-nav-offcanvas" class="offcanvas-item offcanvas-social-navigation">
                        <?php wp_nav_menu(array(
                            'theme_location' => 'dolpa-social-menu',
                            'link_before' => '<span class="screen-reader-text">',
                            'link_after' => '</span>',
                            'container' => 'div',
                            'container_class' => 'social-menu',
                            'depth' => 1,
                        )); ?>
                    </div>
                <?php } ?>

                <a class="skip-link-offcanvas screen-reader-text" href="javascript:void(0)"></a>

            </div>
        </div>
        <?php
    }

endif;

add_action('dolpa_before_footer_content_action', 'dolpa_content_offcanvas', 30);

if (!function_exists('dolpa_footer_content_widget')):

    function dolpa_footer_content_widget()
    {
        $dolpa_default = dolpa_get_default_theme_options();
        if (is_active_sidebar('dolpa-footer-widget-0') ||
            is_active_sidebar('dolpa-footer-widget-1') ||
            is_active_sidebar('dolpa-footer-widget-2')):
            $x = 1;
            $footer_sidebar = 0;
            do {
                if ($x == 3 && is_active_sidebar('dolpa-footer-widget-2')) {
                    $footer_sidebar++;
                }
                if ($x == 2 && is_active_sidebar('dolpa-footer-widget-1')) {
                    $footer_sidebar++;
                }
                if ($x == 1 && is_active_sidebar('dolpa-footer-widget-0')) {
                    $footer_sidebar++;
                }
                $x++;
            } while ($x <= 3);
            if ($footer_sidebar == 1) {
                $footer_sidebar_class = 12;
            } elseif ($footer_sidebar == 2) {
                $footer_sidebar_class = 6;
            } else {
                $footer_sidebar_class = 4;
            }
            $dolpa_footer_columns = absint(get_theme_mod('dolpa_footer_columns', $dolpa_default['dolpa_footer_columns'])); ?>
            <div class="footer-widgetarea">
                <div class="wrapper">
                    <div class="wrapper-inner">
                        <?php if (is_active_sidebar('dolpa-footer-widget-0')): ?>
                            <div class="column column-xs-12 <?php echo 'column-' . absint($footer_sidebar_class); ?>">
                                <div class="widget-wrapper">
                                    <?php dynamic_sidebar('dolpa-footer-widget-0'); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                        <?php if (is_active_sidebar('dolpa-footer-widget-1')): ?>
                            <div class="column column-xs-12 <?php echo 'column-' . absint($footer_sidebar_class); ?>">
                                <div class="widget-wrapper">
                                    <?php dynamic_sidebar('dolpa-footer-widget-1'); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                        <?php if (is_active_sidebar('dolpa-footer-widget-2')): ?>
                            <div class="column column-xs-12 <?php echo 'column-' . absint($footer_sidebar_class); ?>">
                                <div class="widget-wrapper">
                                    <?php dynamic_sidebar('dolpa-footer-widget-2'); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php
        endif;
    }

endif;

add_action('dolpa_footer_content_widget_action', 'dolpa_footer_content_widget', 10);

if (!function_exists('dolpa_footer_content_info')):

    /**
     * Footer Copyright Area
     **/
    function dolpa_footer_content_info()
    {
        $dolpa_default = dolpa_get_default_theme_options(); ?>
        <div class="site-info">
            <div class="wrapper">
                <div class="wrapper-inner">

                    <?php
                    $dolpa_header_layout = get_theme_mod( 'dolpa_header_layout', $dolpa_default['dolpa_header_layout'] );
                    if( $dolpa_header_layout !='layout-default' ){ ?>
                        <div class="column column-12">
                            <div class="footer-credits">
                                <div class="footer-copyright">
                                    <?php
                                    $dolpa_copyright_text = wp_kses_post(get_theme_mod('dolpa_copyright_text', $dolpa_default['dolpa_copyright_text']));
                                    echo esc_html__('Copyright ', 'dolpa') . '&copy ' . absint(date('Y')) . ' <a href="' . esc_url(home_url('/')) . '" title="' . esc_attr(get_bloginfo('name', 'display')) . '" ><span>' . esc_html(get_bloginfo('name', 'display')) . '. </span></a> ' . esc_html($dolpa_copyright_text);
                                    
                                        echo '<br>';
                                        echo esc_html__('Theme: ', 'dolpa') . 'Dolpa ' . esc_html__('By ', 'dolpa') . '<a href="' . esc_url('https://www.themeinwp.com/theme/dolpa') . '"  title="' . esc_attr__('ThemeInWP', 'dolpa') . '" target="_blank" rel="author"><span>' . esc_html__('ThemeInWP. ', 'dolpa') . '</span></a>';
                                        echo esc_html__('Powered by ', 'dolpa') . '<a href="' . esc_url('https://wordpress.org') . '" title="' . esc_attr__('WordPress', 'dolpa') . '" target="_blank"><span>' . esc_html__('WordPress.', 'dolpa') . '</span></a>';
                                    
                                    ?>
                                </div>
                            </div>
                        </div>
                    <?php } ?>
                    
                    <?php if (has_nav_menu('dolpa-footer-menu')) { ?>
                        <div class="column column-12">
                            <div class="footer-navigation">
                                <?php wp_nav_menu(array(
                                    'theme_location' => 'dolpa-footer-menu',
                                    'container' => 'div',
                                    'depth' => 1,
                                    'container_class' => 'footer-navigation-area'
                                )); ?>
                            </div>
                        </div>
                    <?php } ?>

                </div>
            </div>
        </div>
        <?php
    }

endif;

add_action('dolpa_footer_content_info_action', 'dolpa_footer_content_info', 20);

if (!function_exists('dolpa_aside_banner_post_id')):

    function dolpa_aside_banner_post_id()
    {
        if (is_page_template('templates/template-aside-metro.php')) {
            $banner_post_id = get_theme_mod('template_aside_metro_banner_post_id');
        } elseif (is_page_template('templates/template-aside-lateral.php')) {
            $banner_post_id = get_theme_mod('template_aside_lateral_banner_post_id');
        } else {
            $banner_post_id = get_theme_mod('template_aside_default_banner_post_id');
        }
        if (!$banner_post_id) {
            $aside_post_query = new WP_Query(array('post_type' => 'post', 'ignore_sticky_posts' => 1));
            if ($aside_post_query->have_posts()):
                while ($aside_post_query->have_posts()):
                    $aside_post_query->the_post();
                    $banner_post_id = get_the_ID();
                endwhile;
                wp_reset_postdata();
            endif;
        }
        return $banner_post_id;
    }

endif;

if (!function_exists('dolpa_aside_banner_post')):

    function dolpa_aside_banner_post()
    {
        $banner_post_id = dolpa_aside_banner_post_id();
        $aside_post_query = new WP_Query(array('post_type' => 'post', 'post__in' => array($banner_post_id), 'ignore_sticky_posts' => 1));
        if ($aside_post_query->have_posts()):
            while ($aside_post_query->have_posts()):
                $aside_post_query->the_post();
                $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>
                <div class="featured-banner-block">
                    <article id="post-<?php the_ID(); ?>" <?php post_class('theme-article'); ?>>

                        <div class="post-thumbnail">
                            <a href="<?php the_permalink(); ?>">
                                <span class="data-bg-featured data-bg" data-background="<?php echo esc_url($featured_image); ?>"></span>
                            </a>
                        </div>

                        <div class="post-content">
                            <div class="wrapper featured-banner-wrapper">
                                <div class="entry-meta">
                                    <?php dolpa_entry_footer($cats = true, $tags = false, $edits = false, $icon = false, $text = false); ?>
                                </div>
                                <header class="entry-header">
                                    <h1 class="entry-title entry-title-large aaa">
                                        <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title(); ?>">
                                            <?php the_title(); ?>
                                        </a>
                                    </h1>
                                </header>
                                <div class="entry-meta">
                                    <?php
                                    dolpa_posted_on();
                                    dolpa_posted_by();
                                    ?>
                                </div>
                                <div class="entry-excerpt">
                                    <?php
                                    if (has_excerpt()) {
                                        the_excerpt();
                                    } else {
                                        echo esc_html(wp_trim_words(get_the_content(), 25, '...'));
                                    } ?>
                                </div>
                            </div>
                        </div>
                    </article>
                </div>
            <?php
            endwhile;
            wp_reset_postdata();
        endif;
    }

endif;

add_action('dolpa_aside_banner_post_action', 'dolpa_aside_banner_post');

if (!function_exists('dolpa_aside_latest_default_post')):

    function dolpa_aside_latest_default_post()
    {
        
        if( is_front_page() ){
            
            $banner_post_id = dolpa_aside_banner_post_id();
            global $c_paged;
            $c_paged = ( get_query_var( 'page' ) ) ? absint( get_query_var( 'page' ) ) : 1;
            $aside_default_post_query = new WP_Query( array( 'post_type'=>'post', 'paged'=>$c_paged,'post__not_in' => array($banner_post_id) ) );
            

        }else{

            $banner_post_id = dolpa_aside_banner_post_id();
            $twp_paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
            $aside_default_post_query = new WP_Query( array( 'post_type'=>'post', 'paged'=>$twp_paged,'post__not_in' => array($banner_post_id) ) );
            
        }

        if ($aside_default_post_query->have_posts()): ?>

            <div class="latest-blog-block latest-blog-block-1">
                <div class="wrapper">

                    <div class="wrapper-inner">
                        <div id="primary" class="content-area">
                            <main id="site-content" role="main">
                                <div class="article-wraper latest-blog-wrapper">

                                    <?php
                                    while ($aside_default_post_query->have_posts()):
                                        $aside_default_post_query->the_post();
                                        $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                                        $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>

                                        <article id="post-<?php the_ID(); ?>" <?php post_class('theme-article-pagination theme-article'); ?>
                                                 data-aos="fade-up">

                                            <div class="post-thumbnail">
                                                    <div class="post-thumbnail-effects">
                                                        <a href="<?php the_permalink(); ?>">
                                                            <span class="data-bg-default data-bg" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                                        </a>
                                                        <?php
                                                        $format = get_post_format(get_the_ID()) ?: 'standard';
                                                        $icon = dolpa_post_format_icon($format);
                                                        if (!empty($icon)) { ?>
                                                            <div class="post-format-icon">
                                                                <i class="ion <?php echo esc_attr($icon); ?>"></i>
                                                            </div>
                                                        <?php } ?>
                                                    </div>
                                                    <div class="post-thumbnail-overlay">
                                                        <div class="entry-meta">
                                                            <?php dolpa_entry_footer($cats = true, $tags = false, $edits = false, $icon = false, $text = false); ?>
                                                        </div>
                                                    </div>
                                                </div>

                                            <div class="post-content">
                                                <div class="entry-meta">
                                                    <?php dolpa_posted_on(); ?>
                                                    <?php dolpa_posted_by(); ?>
                                                </div>
                                                <header class="entry-header">
                                                    <h3 class="entry-title entry-title-medium">
                                                        <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title(); ?>"><?php the_title(); ?></a>
                                                    </h3>
                                                </header>
                                                <div class="entry-excerpt entry-excerpt-muted">
                                                    <?php
                                                    if (has_excerpt()) {
                                                        the_excerpt();
                                                    } else {
                                                        echo esc_html(wp_trim_words(get_the_content(), 25, '...'));
                                                    } ?>
                                                </div>
                                            </div>

                                        </article>

                                    <?php endwhile; ?>

                                </div>
                            </main>
                        </div>
                    </div>

                    <?php do_action('dolpa_archive_pagination'); ?>

                </div>
            </div>

        <?php
        endif;
    }

endif;


add_action('dolpa_aside_latest_default_post_action', 'dolpa_aside_latest_default_post');

if (!function_exists('dolpa_aside_latest_lateral_post')):

    function dolpa_aside_latest_lateral_post()
    {
        if( is_front_page() ){
            
            $banner_post_id = dolpa_aside_banner_post_id();
            global $c_paged;
            $c_paged = ( get_query_var( 'page' ) ) ? absint( get_query_var( 'page' ) ) : 1;
            $aside_lateral_post_query = new WP_Query( array( 'post_type'=>'post', 'paged'=>$c_paged,'post__not_in' => array($banner_post_id) ) );
            

        }else{

            $banner_post_id = dolpa_aside_banner_post_id();
            $twp_paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
            $aside_lateral_post_query = new WP_Query( array( 'post_type'=>'post', 'paged'=>$twp_paged,'post__not_in' => array($banner_post_id) ) );
            
        }
        
        if ($aside_lateral_post_query->have_posts()): ?>

            <div class="latest-blog-block latest-blog-block-2">
                <div class="wrapper">

                    <div class="wrapper-inner">
                        <div id="primary" class="content-area">
                            <main id="site-content" role="main">
                                <div class="article-wraper latest-blog-wrapper">

                                    <?php
                                    while ($aside_lateral_post_query->have_posts()):
                                        $aside_lateral_post_query->the_post();

                                        $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large');
                                        $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>
                                        <article id="post-<?php the_ID(); ?>" <?php post_class('theme-article-pagination theme-article'); ?> data-aos="fade-up">

                                            <div class="post-thumbnail">

                                                <div class="post-thumbnail-effects">

                                                    <a href="<?php the_permalink(); ?>">
                                                        <span class="data-bg-lateral data-bg" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                                    </a>

                                                    <?php
                                                    $format = get_post_format(get_the_ID()) ?: 'standard';
                                                    $icon = dolpa_post_format_icon($format);

                                                    if (!empty($icon)) { ?>
                                                        <div class="post-format-icon">
                                                            <i class="ion <?php echo esc_attr($icon); ?>"></i>
                                                        </div>
                                                    <?php } ?>

                                                </div>

                                                <div class="post-thumbnail-overlay">
                                                    <div class="entry-meta">

                                                        <?php dolpa_entry_footer($cats = true, $tags = false, $edits = false, $icon = false, $text = false); ?>

                                                    </div>
                                                </div>

                                            </div>

                                            <div class="post-content">

                                                <header class="entry-header">
                                                    <h3 class="entry-title entry-title-medium">
                                                        <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title(); ?>"><?php the_title(); ?></a>
                                                    </h3>
                                                </header>

                                                <div class="entry-meta">
                                                    <?php dolpa_posted_on(); ?>
                                                    <?php dolpa_posted_by(); ?>
                                                </div>

                                                <div class="entry-excerpt entry-excerpt-muted">
                                                    <?php
                                                    if (has_excerpt()) {
                                                        the_excerpt();
                                                    } else {
                                                        echo esc_html(wp_trim_words(get_the_content(), 25, '...'));
                                                    } ?>
                                                </div>

                                            </div>
                                        </article>
                                    <?php endwhile; ?>

                                </div>
                            </main>
                        </div>
                    </div>

                    <?php do_action('dolpa_archive_pagination'); ?>

                </div>
            </div>
        <?php
        endif;
    }

endif;

add_action('dolpa_aside_latest_lateral_post_action', 'dolpa_aside_latest_lateral_post');

if (!function_exists('dolpa_aside_latest_metro_post')):

    function dolpa_aside_latest_metro_post()
    {   

        if( is_front_page() ){
            
            $banner_post_id = dolpa_aside_banner_post_id();
            global $c_paged;
            $c_paged = ( get_query_var( 'page' ) ) ? absint( get_query_var( 'page' ) ) : 1;
            $aside_metro_post_query = new WP_Query( array( 'post_type'=>'post', 'paged'=>$c_paged,'post__not_in' => array($banner_post_id) ) );
            

        }else{

            $banner_post_id = dolpa_aside_banner_post_id();
            $twp_paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
            $aside_metro_post_query = new WP_Query( array( 'post_type'=>'post', 'paged'=>$twp_paged,'post__not_in' => array($banner_post_id) ) );
            
        }

        

        if ($aside_metro_post_query->have_posts()): ?>

            <div class="latest-blog-block latest-blog-block-3">
                <div class="wrapper">
                    
                    <div class="wrapper-inner">
                        <div id="primary" class="content-area">
                            <main id="site-content" role="main">
                                <div class="article-wraper latest-blog-wrapper  template-posts-load">

                                    <?php
                                    $metrocount = 1;
                                    while ($aside_metro_post_query->have_posts()):
                                        $aside_metro_post_query->the_post();

                                        $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                                        $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : '';
                                        if ($metrocount == '2' || $metrocount == '3') {
                                            $metro_item = 'article-item-2';
                                        } else {
                                            $metro_item = 'article-item-1';
                                        } ?>

                                        <article id="post-<?php the_ID(); ?>" <?php post_class('theme-article-pagination theme-article ' . $metro_item); ?> data-aos="fade-up">

                                            <div class="post-thumbnail">

                                                <div class="post-thumbnail-effects">
                                                    <a href="<?php the_permalink(); ?>">
                                                        <span class="data-bg-metro data-bg" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                                    </a>

                                                    <?php
                                                    $format = get_post_format(get_the_ID()) ?: 'standard';
                                                    $icon = dolpa_post_format_icon($format);

                                                    if (!empty($icon)) { ?>

                                                        <div class="post-format-icon">
                                                            <i class="ion <?php echo esc_attr($icon); ?>"></i>
                                                        </div>

                                                    <?php } ?>

                                                </div>

                                                <div class="post-thumbnail-overlay">
                                                    <div class="entry-meta">
                                                        <?php dolpa_entry_footer($cats = true, $tags = false, $edits = false, $icon = false, $text = false); ?>
                                                    </div>
                                                </div>

                                            </div>

                                            <div class="post-content">

                                                <div class="entry-meta">
                                                    <?php dolpa_posted_on(); ?>
                                                    <?php dolpa_posted_by(); ?>
                                                </div>

                                                <header class="entry-header">
                                                    <h3 class="entry-title entry-title-medium">
                                                        <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title(); ?>">
                                                            <?php the_title(); ?>
                                                        </a>
                                                    </h3>
                                                </header>

                                            </div>

                                        </article>

                                        <?php
                                        $metrocount++;
                                        if ($metrocount == '4') {
                                            $metrocount = 1;
                                        }

                                    endwhile; ?>

                                </div>
                            </main>
                        </div>
                    </div>

                    <?php do_action('dolpa_archive_pagination'); ?>

                </div>
            </div>

        <?php
        endif;
    }

endif;

add_action('dolpa_aside_latest_metro_post_action', 'dolpa_aside_latest_metro_post');

if (!function_exists('dolpa_disable_post_views')):

    /** Disable Post Views **/
    function dolpa_disable_post_views()
    {
        add_filter('booster_extension_filter_views_ed', function () {
            return false;
        });
    }

endif;

if (!function_exists('dolpa_disable_post_read_time')):
    /** Disable Read Time **/
    function dolpa_disable_post_read_time()
    {
        add_filter('booster_extension_filter_readtime_ed', function () {
            return false;
        });
    }
endif;

if (!function_exists('dolpa_disable_post_like_dislike')):

    /** Disable Like Dislike **/
    function dolpa_disable_post_like_dislike()
    {
        add_filter('booster_extension_filter_like_ed', function () {
            return false;
        });
    }

endif;

if (!function_exists('dolpa_disable_post_author_box')):

    /** Disable Author Box **/
    function dolpa_disable_post_author_box()
    {
        add_filter('booster_extension_filter_ab_ed', function () {
            return false;
        });
    }

endif;

add_filter('booster_extension_filter_ss_ed', function () {
    return false;
});

if (!function_exists('dolpa_disable_post_reaction')):

    /** Disable Reaction **/
    function dolpa_disable_post_reaction()
    {
        add_filter('booster_extension_filter_reaction_ed', function () {
            return false;
        });
    }

endif;

if (!function_exists('dolpa_post_view_count')):

    function dolpa_post_view_count()
    {
        $twp_be_settings = get_option('twp_be_options_settings');
        $twp_be_enable_post_visit_tracking = isset($twp_be_settings['twp_be_enable_post_visit_tracking']) ? esc_html($twp_be_settings['twp_be_enable_post_visit_tracking']) : '';
        if ($twp_be_enable_post_visit_tracking && class_exists('Booster_Extension_Class')): ?>
            <div class="entry-meta-item entry-meta-views">
                <div class="entry-meta-wrapper">
                    <span class="entry-meta-icon views-icon">
                        <?php dolpa_the_theme_svg('viewer'); ?>
                    </span>
                    <a href="<?php the_permalink(); ?>">
                        <span class="post-view-count">
                           <?php
                           echo do_shortcode('[booster-extension-visit-count count_only="count" label="' . esc_html__('Views', 'dolpa') . '"]');
                           ?>
                        </span>
                    </a>
                </div>
            </div>
        <?php
        endif;
    }

endif;

if (!function_exists('dolpa_post_like_dislike')):

    function dolpa_post_like_dislike()
    {
        $dolpa_ed_post_like_dislike = esc_html(get_post_meta(get_the_ID(), 'dolpa_ed_post_like_dislike', true));
        if (class_exists('Booster_Extension_Class') && !$dolpa_ed_post_like_dislike): ?>
            <div class="entry-meta-item entry-meta-like-dislike">
                <div class="entry-meta-wrapper">
                    <?php echo do_shortcode('[booster-extension-like-dislike]'); ?>
                </div>
            </div>
        <?php
        endif;
    }

endif;

if (!function_exists('dolpa_post_format_icon')):

    // Post Format Icon.
    function dolpa_post_format_icon($format)
    {
        if ($format == 'video') {
            $icon = 'ion-ios-videocam';
        } elseif ($format == 'audio') {
            $icon = 'ion-ios-musical-notes';
        } elseif ($format == 'gallery') {
            $icon = 'ion-md-images';
        } elseif ($format == 'quote') {
            $icon = 'ion-md-quote';
        } elseif ($format == 'image') {
            $icon = 'ion-ios-camera';
        } else {
            $icon = '';
        }
        return $icon;
    }

endif;

if (!function_exists('dolpa_hex2rgb')):

    function dolpa_hex2rgb( $colour,$opacity = 1 ) {

        if ( $colour[0] == '#' ) {
            $colour = substr( $colour, 1 );
        }
        if ( strlen( $colour ) == 6 ) {
            list( $r, $g, $b ) = array( $colour[0] . $colour[1], $colour[2] . $colour[3], $colour[4] . $colour[5] );
        } elseif ( strlen( $colour ) == 3 ) {
            list( $r, $g, $b ) = array( $colour[0] . $colour[0], $colour[1] . $colour[1], $colour[2] . $colour[2] );
        } else {
            return false;
        }
        $r = hexdec( $r );
        $g = hexdec( $g );
        $b = hexdec( $b );
        return 'rgba('.$r.','.$g.','.$b.','.$opacity.')';

    }

endif;

if( class_exists( 'Booster_Extension_Class' ) ){

    add_filter('booster_extemsion_content_after_filter','dolpa_after_content_pagination');

}

if( !function_exists('dolpa_after_content_pagination') ):

    function dolpa_after_content_pagination($after_content){

        $pagination_single = wp_link_pages( array(
                    'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'dolpa' ),
                    'after'  => '</div>',
                    'echo' => false
                ) );

        $after_content =  $pagination_single.$after_content;

        return $after_content;

    }

endif;